@@ -1,10 +1,10 @@
 from bisect import bisect_right
 from PyQt5.QtCore import Qt, QAbstractItemModel, QAbstractTableModel, QModelIndex
 from PyQt5.QtGui import QBrush
-from .dwex_elftools.dwarf.locationlists import LocationParser, LocationExpr
-from .dwex_elftools.dwarf.dwarf_expr import DWARFExprParser, DWARFExprOp, DW_OP_opcode2name
+from elftools.dwarf.locationlists import LocationParser, LocationExpr
+from elftools.dwarf.dwarf_expr import DWARFExprParser, DWARFExprOp, DW_OP_opcode2name
+from elftools.dwarf.descriptions import _DESCR_DW_LANG, _DESCR_DW_ATE, _DESCR_DW_ACCESS, _DESCR_DW_INL, _REG_NAMES_x86, _REG_NAMES_x64
 from .dwarfone import DWARFExprParserV1
-from .dwex_elftools.dwarf.descriptions import _DESCR_DW_LANG, _DESCR_DW_ATE, _DESCR_DW_ACCESS, _DESCR_DW_INL, _REG_NAMES_x86, _REG_NAMES_x64
 
 _REG_NAMES_ARM = [
     'r0', 'r1', 'r2', 'r3', 'r4', 'r5', 'r6', 'r7',
@@ -31,7 +31,7 @@ _REG_NAMES_MIPS = [
 
 # The key here is the machine_arch value in the DWARFConfig struct.
 # Machine arch values are generated differently for ELF, MachO and PE
-# For ELF, see the values in the architecture dict in get_machine_arch() under dwex_elftools.elf.elffile
+# For ELF, see the values in the architecture dict in get_machine_arch() under elftools.elf.elffile
 # For PE, see IMAGE_FILE_MACHINE in filebytes.pe
 # For MachO, see make_macho_arch_name() in formats.py
 
@@ -262,7 +262,7 @@ class DIETableModel(QAbstractTableModel):
         val = attr.raw_value
         if isinstance(val, int):
             return hex(val) if self.hex else str(val)
-        elif isinstance(val, bytes) or (isinstance(val, list) and isinstance(val[0], int)):
+        elif isinstance(val, bytes) or (isinstance(val, list) and len(val) > 0 and isinstance(val[0], int)):
             return ' '.join("%02x" % b for b in val) if len(val) > 0 else '[]'
         else:
             return str(val)
@@ -390,7 +390,7 @@ class DIETableModel(QAbstractTableModel):
         elif attr.form in ('DW_FORM_ref_addr', 'DW_FORM_ref'):
             i = bisect_right(self.die.cu.dwarfinfo._CU_offsets, attr.value) - 1
             # Any chance for "not found"?
-            cu = self.die.cu.dwarfinfo._CU_dict[i]
+            cu = self.die.cu.dwarfinfo._unsorted_CUs[i]
             return (cu, attr.value)
 
 class GenericTableModel(QAbstractTableModel):
